@@ -49,7 +49,7 @@ def connected(*,
         The param ``enable_real_trading`` must be set to True to work on live accounts.
     """
     args = locals().copy()
-    args = helpers.clean_args(args)
+    args = helpers.reduce_args(args)
     mt5_keys = ('path', 'portable', 'server', 'login', 'password', 'timeout')
     mt5_kwargs = {k: v for k, v in args.items() if k in mt5_keys}
     _state.global_debugging = bool(debug_logging)
@@ -62,14 +62,17 @@ def connected(*,
             raise MT5Error(*last_error())
         elif debug_logging:
             log("MT5 connection has been initialized.")
-        if not enable_real_trading and account_info().trade_mode == const.ACCOUNT_TRADE_MODE_REAL:
+        acc_info = account_info()
+        if not enable_real_trading and acc_info.trade_mode == const.ACCOUNT_TRADE_MODE_REAL:
             raise MT5Error(
                 const.RES_X_REAL_ACCOUNT_DISABLED,
                 "REAL ACCOUNT TRADING HAS NOT BEEN ENABLED IN THE CONTEXT MANAGER")
-        if ensure_trade_enabled and not terminal_info().trade_allowed:
+        term_info = terminal_info()
+        if ensure_trade_enabled and not term_info.trade_allowed:
             if debug_logging:
                 log("Failed to initialize because auto-trade is disabled in terminal.")
             raise MT5Error(const.RES_X_AUTO_TRADE_DISABLED, "Terminal Auto-Trading is disabled.")
+        _state.max_bars = term_info.maxbars
         yield
     finally:
         shutdown()
