@@ -60,7 +60,7 @@ def initialize(path: str = None,
     :return: Returns True in case of successful connection to the MetaTrader 5 terminal, otherwise - False.
     """
     args = locals().copy()
-    args = _h.clean_args(args)
+    args = _h.reduce_args(args)
     result = _mt5.initialize(**args)
     return result
 
@@ -82,7 +82,7 @@ def login(login: int, *,
     :return: True if success.
     """
     args = locals().copy()
-    args = _h.clean_args(args)
+    args = _h.reduce_args(args)
     login = args.pop('login')
     return _mt5.login(login, **args)
 
@@ -328,7 +328,7 @@ def copy_rates(symbol,
                 return _mt5.copy_rates_range(symbol, timeframe, datetime_from, datetime_to)
         if all(x is None for x in [datetime_from, datetime_to, start_pos]):
             start_pos = 0
-        count = count or _const.MAX_BARS
+        count = count or _state.max_bars
         return _mt5.copy_rates_from_pos(symbol, timeframe, start_pos, count)
     except SystemError:
         return None
@@ -562,7 +562,6 @@ def order_send(request: dict = None,
     :param kwargs:
     :return: OrderSendResult namedtuple
     """
-    symbol = _h.any_symbol(symbol)
     args = locals().copy()
     return _h.do_trade_action(_mt5.order_send, args)
 
